@@ -22,7 +22,6 @@ from nonebot_plugin_chatrecorder import get_message_records
 
 from .config import plugin_config
 from .data_source import get_wordcloud
-from .migrate import migrate_database
 
 wordcloud_cmd = on_command(
     "wordcloud",
@@ -49,16 +48,21 @@ wordcloud_cmd.__doc__ = """
 /今日词云
 获取昨天的词云
 /昨日词云
-获取年度词云
-/年度词云
 获取本周词云
 /本周词云
 获取本月词云
 /本月词云
-获取历史词云，支持 ISO8601 格式的日期，如 2020-02-22
-/历史词云
+获取年度词云
+/年度词云
+
+历史词云(支持 ISO8601 格式的日期与时间，如 2022-02-22T22:22:22)
+获取某日的词云
 /历史词云 2022-01-01
+获取指定时间段的词云
+/历史词云
 /历史词云 2022-01-01~2022-02-22
+/历史词云 2022-02-22T11:11:11~2022-02-22T22:22:22
+
 如果想要获取自己的发言，可在命令前添加 我的
 /我的今日词云
 """
@@ -79,7 +83,7 @@ def parse_datetime(key: str):
         try:
             state[key] = get_datetime_fromisoformat_with_timezone(plaintext)
         except ValueError:
-            await matcher.reject_arg(key, "请输入正确的日期（如 2022-02-22），不然我没法理解呢！")
+            await matcher.reject_arg(key, "请输入正确的日期，不然我没法理解呢！")
 
     return _key_parser
 
@@ -143,10 +147,7 @@ async def handle_first_receive(
         state["stop"] = dt
     elif command == "历史词云":
         plaintext = args.extract_plain_text().strip()
-        match = re.match(
-            r"^([0-9]{4}-[0-9]{2}-[0-9]{2})(?:~([0-9]{4}-[0-9]{2}-[0-9]{2}))?$",
-            plaintext,
-        )
+        match = re.match(r"^(.+?)(?:~(.+))?$", plaintext)
         if match:
             start = match.group(1)
             stop = match.group(2)
@@ -155,12 +156,21 @@ async def handle_first_receive(
                 if stop:
                     state["stop"] = get_datetime_fromisoformat_with_timezone(stop)
                 else:
+                    # 如果没有指定结束日期，则认为是指查询这一天的词云
+                    state["start"] = state["start"].replace(
+                        hour=0, minute=0, second=0, microsecond=0
+                    )
                     state["stop"] = state["start"] + timedelta(days=1)
             except ValueError:
-                await wordcloud_cmd.finish("请输入正确的日期（如 2022-02-22），不然我没法理解呢！")
+                await wordcloud_cmd.finish("请输入正确的日期，不然我没法理解呢！")
     else:
-        help_msg = cleandoc(wordcloud_cmd.__doc__) if wordcloud_cmd.__doc__ else ""
-        await wordcloud_cmd.finish(help_msg)
+        plaintext = args.extract_plain_text()
+        # 当完整匹配词云的时候才输出帮助信息
+        if not plaintext:
+            help_msg = cleandoc(wordcloud_cmd.__doc__) if wordcloud_cmd.__doc__ else ""
+            await wordcloud_cmd.finish(help_msg)
+        else:
+            await wordcloud_cmd.finish()
 
 
 @wordcloud_cmd.got(
@@ -203,15 +213,3 @@ async def handle_message(
         await wordcloud_cmd.finish(MessageSegment.image(image_bytes), at_sender=my)
     else:
         await wordcloud_cmd.finish("没有足够的数据生成词云", at_sender=my)
-
-
-migrate_cmd = on_command("迁移词云")
-
-
-@migrate_cmd.handle()
-async def handle_migrate():
-    result = await migrate_database()
-    if result:
-        await migrate_cmd.finish("数据库迁移成功")
-    else:
-        await migrate_cmd.finish("旧版本数据库不存在，不需要迁移")
