@@ -16,4 +16,4 @@ class Config(BaseModel, extra=Extra.ignore):
 
 
 global_config = get_driver().config
-plugin_config = Config.parse_obj(global_config.dict())
+plugin_config = Config.parse_obj(global_config)
